@@ -11,13 +11,13 @@ Net::SNTP::Server - Perl Module SNTP Server based on L<RFC4330|https://tools.iet
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
 ## Version of the Net::SNTP::Server module
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 $VERSION = eval $VERSION;
 
 use POSIX qw();
@@ -459,6 +459,11 @@ perl, IO::Socket, Net::SNTP::Client, L<RFC4330|https://tools.ietf.org/html/rfc43
 Net::NTP has a similar focus as this module. In my opinion it
  is less accurate when it comes to the precission bellow second(s).
 
+=head1 REPOSITORY
+
+L<https://github.com/thanos1983/perl5-Net-SNTP-Server>
+
+
 =head1 DIFFERENCES BETWEEN NTP AND SNTP
 
 SNTP (Simple Network Time Protocol) and NTP (Network Time Protocol)
@@ -516,7 +521,7 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =head1 CHANGE LOG
 
 $Log: Server.pm,v $
-Revision 3.0  2015/10/08 5:25:31 pm  Thanos
+Revision 4.0  2015/10/09 6:43:31 pm  Thanos
 
 
 =cut
